pub struct DependencyExclusion {
pub tool_id: String,
pub unmet_requires: Vec<String>,
}Expand description
Exclusion reason for a tool that was blocked by the dependency gate.
Fields
tool_id: Stringunmet_requires: Vec<String>IDs of requires entries that are not yet satisfied.