pub fn save_overflow(output: &str, config: &OverflowConfig) -> Option<String>Expand description
Save full output to overflow file if it exceeds config.threshold.
Returns the filename (UUID.txt) of the saved file, or None if output fits.
pub fn save_overflow(output: &str, config: &OverflowConfig) -> Option<String>Save full output to overflow file if it exceeds config.threshold.
Returns the filename (UUID.txt) of the saved file, or None if output fits.