Structs
- Shell
Executor - Bash block extraction and execution via
tokio::process::Command.
Constants
- DEFAULT_
BLOCKED_ COMMANDS - The default list of blocked command patterns used by
ShellExecutor. - SHELL_
INTERPRETERS - Shell interpreters that may execute arbitrary code via
-cor positional args.
Functions
- check_
blocklist - Check if
commandmatches any pattern inblocklist. - effective_
shell_ command - Build the effective command string for blocklist evaluation when the binary is a
shell interpreter (bash, sh, zsh, etc.) and args contains a
-cscript.