Module shell

Module shell 

Structs

ShellExecutor
Bash block extraction and execution via tokio::process::Command.

Constants

DEFAULT_BLOCKED_COMMANDS
The default list of blocked command patterns used by ShellExecutor.
SHELL_INTERPRETERS
Shell interpreters that may execute arbitrary code via -c or positional args.

Functions

check_blocklist
Check if command matches any pattern in blocklist.
effective_shell_command
Build the effective command string for blocklist evaluation when the binary is a shell interpreter (bash, sh, zsh, etc.) and args contains a -c script.